==> aws-java-sdk-route53-1.9.3-sources.jar: com/amazonaws/services/route53/model/transform/HostedZoneConfigStaxUnmarshaller.java <==
/*
 * Copyright 2010-2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.route53.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.route53.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * Hosted Zone Config StAX Unmarshaller
 */
public class HostedZoneConfigStaxUnmarshaller implements Unmarshaller<HostedZoneConfig, StaxUnmarshallerContext> {

    public HostedZoneConfig unmarshall(StaxUnmarshallerContext context) throws Exception {
        HostedZoneConfig hostedZoneConfig = new HostedZoneConfig();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;
        if (context.isStartOfDocument()) targetDepth += 1;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument()) return hostedZoneConfig;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {
                if (context.testExpression("Comment", targetDepth)) {
                    hostedZoneConfig.setComment(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return hostedZoneConfig;
                }
            }
        }
    }

    private static HostedZoneConfigStaxUnmarshaller instance;
    public static HostedZoneConfigStaxUnmarshaller getInstance() {
        if (instance == null) instance = new HostedZoneConfigStaxUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-route53-1.10.15-sources.jar: com/amazonaws/services/route53/model/transform/HostedZoneConfigStaxUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.route53.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.route53.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * Hosted Zone Config StAX Unmarshaller
 */
public class HostedZoneConfigStaxUnmarshaller implements Unmarshaller<HostedZoneConfig, StaxUnmarshallerContext> {

    public HostedZoneConfig unmarshall(StaxUnmarshallerContext context) throws Exception {
        HostedZoneConfig hostedZoneConfig = new HostedZoneConfig();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;
        if (context.isStartOfDocument()) targetDepth += 1;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument()) return hostedZoneConfig;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {
                if (context.testExpression("Comment", targetDepth)) {
                    hostedZoneConfig.setComment(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("PrivateZone", targetDepth)) {
                    hostedZoneConfig.setPrivateZone(BooleanStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return hostedZoneConfig;
                }
            }
        }
    }

    private static HostedZoneConfigStaxUnmarshaller instance;
    public static HostedZoneConfigStaxUnmarshaller getInstance() {
        if (instance == null) instance = new HostedZoneConfigStaxUnmarshaller();
        return instance;
    }
}
